/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.twotone

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.VectorAsset

val Icons.TwoTone.Hvac: VectorAsset
    get() {
        if (_hvac != null) {
            return _hvac!!
        }
        _hvac = materialIcon {
            materialPath(fillAlpha = 0.3f, strokeAlpha = 0.3f) {
                moveTo(5.0f, 19.0f)
                horizontalLineToRelative(14.0f)
                verticalLineTo(5.0f)
                horizontalLineTo(5.0f)
                verticalLineTo(19.0f)
                close()
                moveTo(12.0f, 6.0f)
                curveToRelative(3.31f, 0.0f, 6.0f, 2.69f, 6.0f, 6.0f)
                reflectiveCurveToRelative(-2.69f, 6.0f, -6.0f, 6.0f)
                reflectiveCurveToRelative(-6.0f, -2.69f, -6.0f, -6.0f)
                reflectiveCurveTo(8.69f, 6.0f, 12.0f, 6.0f)
                close()
            }
            materialPath {
                moveTo(19.0f, 3.0f)
                horizontalLineTo(5.0f)
                curveTo(3.9f, 3.0f, 3.0f, 3.9f, 3.0f, 5.0f)
                verticalLineToRelative(14.0f)
                curveToRelative(0.0f, 1.1f, 0.9f, 2.0f, 2.0f, 2.0f)
                horizontalLineToRelative(14.0f)
                curveToRelative(1.1f, 0.0f, 2.0f, -0.9f, 2.0f, -2.0f)
                verticalLineTo(5.0f)
                curveTo(21.0f, 3.9f, 20.1f, 3.0f, 19.0f, 3.0f)
                close()
                moveTo(19.0f, 19.0f)
                horizontalLineTo(5.0f)
                verticalLineTo(5.0f)
                horizontalLineToRelative(14.0f)
                verticalLineTo(19.0f)
                close()
            }
            materialPath {
                moveTo(12.0f, 18.0f)
                curveToRelative(3.31f, 0.0f, 6.0f, -2.69f, 6.0f, -6.0f)
                reflectiveCurveToRelative(-2.69f, -6.0f, -6.0f, -6.0f)
                reflectiveCurveToRelative(-6.0f, 2.69f, -6.0f, 6.0f)
                reflectiveCurveTo(8.69f, 18.0f, 12.0f, 18.0f)
                close()
                moveTo(12.0f, 16.0f)
                curveToRelative(-1.01f, 0.0f, -1.91f, -0.39f, -2.62f, -1.0f)
                horizontalLineToRelative(5.24f)
                curveTo(13.91f, 15.61f, 13.01f, 16.0f, 12.0f, 16.0f)
                close()
                moveTo(12.0f, 8.0f)
                curveToRelative(1.01f, 0.0f, 1.91f, 0.39f, 2.62f, 1.0f)
                horizontalLineTo(9.38f)
                curveTo(10.09f, 8.39f, 10.99f, 8.0f, 12.0f, 8.0f)
                close()
                moveTo(8.56f, 10.0f)
                horizontalLineToRelative(6.89f)
                curveToRelative(0.26f, 0.45f, 0.44f, 0.96f, 0.51f, 1.5f)
                horizontalLineToRelative(-7.9f)
                curveTo(8.12f, 10.96f, 8.29f, 10.45f, 8.56f, 10.0f)
                close()
                moveTo(15.95f, 12.5f)
                curveToRelative(-0.07f, 0.54f, -0.24f, 1.05f, -0.51f, 1.5f)
                horizontalLineTo(8.56f)
                curveToRelative(-0.26f, -0.45f, -0.44f, -0.96f, -0.51f, -1.5f)
                horizontalLineTo(15.95f)
                close()
            }
        }
        return _hvac!!
    }

private var _hvac: VectorAsset? = null
